exporters Package
=================

:mod:`xlsexporter` Module
-------------------------

.. automodule:: stoqlib.exporters.xlsexporter
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`xlsutils` Module
-------------------------

.. automodule:: stoqlib.exporters.xlsutils
    :members:
    :undoc-members:
    :show-inheritance:

